import * as THREE from "three";
import { TextGeometry } from "three/addons/geometries/TextGeometry.js";
const scene = new THREE.Scene();
const camera = new THREE.PerspectiveCamera(75, window.innerWidth / window.innerHeight, 0.1, 1e3);
const renderer = new THREE.WebGLRenderer();
renderer.setSize(window.innerWidth, window.innerHeight);
document.body.appendChild(renderer.domElement);
const geometry = new THREE.BoxGeometry(1, 1, 1);
const material = new THREE.MeshBasicMaterial({ color: 65280 });
const material2 = new THREE.MeshBasicMaterial({ color: 255 });
const material3 = new THREE.MeshBasicMaterial({ color: 16711680 });
const cube1 = new THREE.Mesh(geometry, material3);
cube1.position.x = -2;
scene.add(cube1);
const d = new TextGeometry("Hello three.js!", {
  size: 80,
  depth: 5,
  curveSegments: 12,
  bevelEnabled: true,
  bevelThickness: 10,
  bevelSize: 8,
  bevelOffset: 0,
  bevelSegments: 5
});
scene.add(d);
const cube2 = new THREE.Mesh(geometry, material);
cube2.position.x = 0;
scene.add(cube2);
const cube3 = new THREE.Mesh(geometry, material2);
cube3.position.x = 2;
scene.add(cube3);
let isDragging = false;
let previousMousePosition = {
  x: 0,
  y: 0
};
function onMouseMove(event) {
  const deltaMove = {
    x: event.offsetX - previousMousePosition.x,
    y: event.offsetY - previousMousePosition.y
  };
  if (isDragging) {
    const deltaRotationQuaternion = new THREE.Quaternion().setFromEuler(new THREE.Euler(
      toRadians(deltaMove.y * 1),
      toRadians(deltaMove.x * 1),
      0,
      "XYZ"
    ));
    cube1.quaternion.multiplyQuaternions(deltaRotationQuaternion, cube1.quaternion);
    cube2.quaternion.multiplyQuaternions(deltaRotationQuaternion, cube2.quaternion);
    cube3.quaternion.multiplyQuaternions(deltaRotationQuaternion, cube3.quaternion);
  }
  previousMousePosition = {
    x: event.offsetX,
    y: event.offsetY
  };
}
function onMouseDown(event) {
  isDragging = true;
}
function onMouseUp(event) {
  isDragging = false;
}
function toRadians(angle) {
  return angle * (Math.PI / 180);
}
window.addEventListener("mousemove", onMouseMove);
window.addEventListener("mousedown", onMouseDown);
window.addEventListener("mouseup", onMouseUp);
camera.position.z = 5;
function animate() {
  requestAnimationFrame(animate);
  renderer.render(scene, camera);
}
animate();
